## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup, message=FALSE-----------------------------------------------------
library(mapme.biodiversity)
library(sf)
library(dplyr)
library(tidyr)

aoi_path <- system.file("extdata", "sierra_de_neiba_478140.gpkg", package = "mapme.biodiversity")
aoi <- st_read(aoi_path, quiet = TRUE)
aoi

## ----simplify-aoi, echo = FALSE-----------------------------------------------
aoi <- st_simplify(aoi, preserveTopology = TRUE, dTolerance = 500)

## ----init-data-dir, echo=FALSE------------------------------------------------
outdir <- file.path(tempdir(), "mapme-resources")
mapme.biodiversity:::.copy_resource_dir(outdir)

## ----portfolio-opts-----------------------------------------------------------
outdir <- file.path(tempdir(), "mapme-resources")
dir.create(outdir, showWarnings = FALSE)

mapme_options(
  outdir = outdir,
  verbose = TRUE
)

## ----query-indicator----------------------------------------------------------
available_indicators()
available_indicators("population_count")

## ----help-indicator, eval = FALSE---------------------------------------------
#  ?population_count
#  help(population_count)

## ----query-resources----------------------------------------------------------
available_resources()
available_resources("worldpop")

## ----help-resource, eval = FALSE----------------------------------------------
#  ?worldpop
#  help(worldpop)

## ----get-worldpop-------------------------------------------------------------
aoi <- get_resources(x = aoi, get_worldpop(years = 2010:2015))

## ----get-multi-resources, eval = FALSE----------------------------------------
#  aoi <- get_resources(
#    x = aoi,
#    get_worldpop(years = 2010:2015),
#    get_gfw_treecover(version = "GFC-2021-v1.9")
#  )

## ----calc-indicator-----------------------------------------------------------
aoi <- calc_indicators(aoi, calc_population_count(engine = "zonal", stats = "sum"))

## ----print-aoi----------------------------------------------------------------
aoi

## ----print-indicator----------------------------------------------------------
aoi$population_count

## ----plot-popcount, echo = FALSE, warning=FALSE-------------------------------
mapme_options(verbose = FALSE)
data <- portfolio_long(aoi)

plot(value ~ datetime, data,
  main = "Population totals over time",
  xlab = "Year", ylab = "Persons",
  pch = 16, col = "steelblue"
)

## ----long-drop-geoms----------------------------------------------------------
geoms <- st_geometry(aoi)
portfolio_long(aoi, drop_geoms = TRUE)

## ----parallel-1, eval = FALSE-------------------------------------------------
#  library(future)
#  plan(list(sequential, tweak(cluster, workers = 6)))

## ----parallel, eval = FALSE---------------------------------------------------
#  library(progressr)
#  
#  plan(list(tweak(cluster, workers = 2), tweak(cluster, workers = 4)))
#  
#  with_progress({
#    aoi <- calc_indicators(
#      aoi,
#      calc_treecover_area_and_emissions(
#        min_size = 1,
#        min_cover = 30
#      )
#    )
#  })
#  
#  plan(sequential) # close child processes

## ----write-portfolio----------------------------------------------------------
dsn <- tempfile(fileext = ".gpkg")
write_portfolio(x = aoi, dsn = dsn, format = "long", quiet = TRUE)
from_disk <- st_read(dsn, quiet = TRUE)
from_disk

## ----delete-dsn, echo=FALSE---------------------------------------------------
file.remove(dsn)

